==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/classes/impl/AttributeDerivationSetImpl.java <==
package io.ciera.tool.sql.architecture.classes.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.AttributeAccessorSet;
import io.ciera.tool.sql.architecture.classes.AttributeDerivation;
import io.ciera.tool.sql.architecture.classes.AttributeDerivationSet;
import io.ciera.tool.sql.architecture.classes.impl.AttributeAccessorSetImpl;
import io.ciera.tool.sql.architecture.invocable.InvocableObjectSet;
import io.ciera.tool.sql.architecture.invocable.impl.InvocableObjectSetImpl;

import java.util.Arrays;
import java.util.List;

import types.AttributeAccessorType;


public class AttributeDerivationSetImpl extends InstanceSet<AttributeDerivationSet,AttributeDerivation> implements AttributeDerivationSet {

    // attributes
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setClass_name( ref_class_name );
    }
    @Override
    public void setAttribute_name( String ref_attribute_name ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setAttribute_name( ref_attribute_name );
    }
    @Override
    public void setAccessor_type( AttributeAccessorType ref_accessor_type ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setAccessor_type( ref_accessor_type );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setClass_package( ref_class_package );
    }


    // selections
    @Override
    public InvocableObjectSet R427_is_a_InvocableObject() throws XtumlException {
        InvocableObjectSet invocableobjectset = new InvocableObjectSetImpl();
        for ( AttributeDerivation attributederivation : this ) invocableobjectset.add( attributederivation.R427_is_a_InvocableObject() );
        return invocableobjectset;
    }
    @Override
    public AttributeAccessorSet R441_calculates_value_for_AttributeAccessor() throws XtumlException {
        AttributeAccessorSet attributeaccessorset = new AttributeAccessorSetImpl();
        for ( AttributeDerivation attributederivation : this ) attributeaccessorset.add( attributederivation.R441_calculates_value_for_AttributeAccessor() );
        return attributeaccessorset;
    }


    @Override
    public AttributeDerivation nullElement() {
        return AttributeDerivationImpl.EMPTY_ATTRIBUTEDERIVATION;
    }

    @Override
    public AttributeDerivationSet emptySet() {
      return new AttributeDerivationSetImpl();
    }

    @Override
    public AttributeDerivationSet value() {
        return this;
    }

    @Override
    public List<AttributeDerivation> elements() {
        return Arrays.asList(toArray(new AttributeDerivation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/classes/impl/AttributeDerivationSetImpl.java <==
package io.ciera.tool.sql.architecture.classes.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.AttributeAccessorSet;
import io.ciera.tool.sql.architecture.classes.AttributeDerivation;
import io.ciera.tool.sql.architecture.classes.AttributeDerivationSet;
import io.ciera.tool.sql.architecture.classes.impl.AttributeAccessorSetImpl;
import io.ciera.tool.sql.architecture.invocable.InvocableObjectSet;
import io.ciera.tool.sql.architecture.invocable.impl.InvocableObjectSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import types.AttributeAccessorType;


public class AttributeDerivationSetImpl extends InstanceSet<AttributeDerivationSet,AttributeDerivation> implements AttributeDerivationSet {

    public AttributeDerivationSetImpl() {
    }

    public AttributeDerivationSetImpl(Comparator<? super AttributeDerivation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setClass_name( ref_class_name );
    }
    @Override
    public void setAttribute_name( String ref_attribute_name ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setAttribute_name( ref_attribute_name );
    }
    @Override
    public void setAccessor_type( AttributeAccessorType ref_accessor_type ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setAccessor_type( ref_accessor_type );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( AttributeDerivation attributederivation : this ) attributederivation.setClass_package( ref_class_package );
    }


    // selections
    @Override
    public InvocableObjectSet R427_is_a_InvocableObject() throws XtumlException {
        InvocableObjectSet invocableobjectset = new InvocableObjectSetImpl();
        for ( AttributeDerivation attributederivation : this ) invocableobjectset.add( attributederivation.R427_is_a_InvocableObject() );
        return invocableobjectset;
    }
    @Override
    public AttributeAccessorSet R441_calculates_value_for_AttributeAccessor() throws XtumlException {
        AttributeAccessorSet attributeaccessorset = new AttributeAccessorSetImpl();
        for ( AttributeDerivation attributederivation : this ) attributeaccessorset.add( attributederivation.R441_calculates_value_for_AttributeAccessor() );
        return attributeaccessorset;
    }


    @Override
    public AttributeDerivation nullElement() {
        return AttributeDerivationImpl.EMPTY_ATTRIBUTEDERIVATION;
    }

    @Override
    public AttributeDerivationSet emptySet() {
      return new AttributeDerivationSetImpl();
    }

    @Override
    public AttributeDerivationSet emptySet(Comparator<? super AttributeDerivation> comp) {
      return new AttributeDerivationSetImpl(comp);
    }

    @Override
    public AttributeDerivationSet value() {
        return this;
    }

    @Override
    public List<AttributeDerivation> elements() {
        return Arrays.asList(toArray(new AttributeDerivation[0]));
    }

}
